@@ -1,7 +1,7 @@
 /*
  * The MIT License
  *
- * Copyright 2012-2015 Zafar Khaja <zafarkhaja@gmail.com>.
+ * Copyright 2012-2024 Zafar Khaja <zafarkhaja@gmail.com>.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -26,11 +26,13 @@ package com.github.zafarkhaja.semver;
 /**
  * Thrown to indicate an error during the parsing.
  *
- * @author Zafar Khaja <zafarkhaja@gmail.com>
+ * @author Zafar Khaja {@literal <zafarkhaja@gmail.com>}
  * @since 0.7.0
  */
 public class ParseException extends RuntimeException {
 
+    private static final long serialVersionUID = 0L;
+
     /**
      * Constructs a {@code ParseException} instance with no error message.
      */
@@ -69,7 +71,7 @@ public class ParseException extends RuntimeException {
         Throwable cause = getCause();
         String msg = getMessage();
         if (msg != null) {
-            msg += ((cause != null) ? " (" + cause.toString() + ")" : "");
+            msg += ((cause != null) ? " (" + cause + ")" : "");
             return msg;
         }
         return ((cause != null) ? cause.toString() : "");
