@@ -1,7 +1,7 @@
 /*
  * The MIT License
  *
- * Copyright 2012-2015 Zafar Khaja <zafarkhaja@gmail.com>.
+ * Copyright 2012-2024 Zafar Khaja <zafarkhaja@gmail.com>.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -29,14 +29,16 @@ import java.util.Arrays;
 
 /**
  * Thrown when attempting to consume a character of unexpected types.
- *
+ * <p>
  * This exception is a wrapper exception extending {@code ParseException}.
  *
- * @author Zafar Khaja <zafarkhaja@gmail.com>
+ * @author Zafar Khaja {@literal <zafarkhaja@gmail.com>}
  * @since 0.8.0
  */
 public class UnexpectedCharacterException extends ParseException {
 
+    private static final long serialVersionUID = 0L;
+
     /**
      * The unexpected character.
      */
@@ -59,9 +61,11 @@ public class UnexpectedCharacterException extends ParseException {
      * @param cause the wrapped exception
      */
     UnexpectedCharacterException(UnexpectedElementException cause) {
-        position   = cause.getPosition();
-        unexpected = (Character) cause.getUnexpectedElement();
-        expected   = (CharType[]) cause.getExpectedElementTypes();
+        this(
+            (Character) cause.getUnexpectedElement(),
+            cause.getPosition(),
+            (CharType[]) cause.getExpectedElementTypes()
+        );
     }
 
     /**
@@ -72,11 +76,9 @@ public class UnexpectedCharacterException extends ParseException {
      * @param position the position of the unexpected character
      * @param expected an array of the expected character types
      */
-    UnexpectedCharacterException(
-        Character unexpected,
-        int position,
-        CharType... expected
-    ) {
+    UnexpectedCharacterException(Character unexpected, int position, CharType... expected) {
+        super(createMessage(unexpected, position, expected));
+
         this.unexpected = unexpected;
         this.position   = position;
         this.expected   = expected;
@@ -118,18 +120,19 @@ public class UnexpectedCharacterException extends ParseException {
      */
     @Override
     public String toString() {
-        String message = String.format(
-            "Unexpected character '%s(%s)' at position '%d'",
+        return getMessage();
+    }
+
+    private static String createMessage(Character unexpected, int position, CharType... expected) {
+        String msg = String.format(
+            "Unexpected character %s(%s) at position %d",
             CharType.forCharacter(unexpected),
             unexpected,
             position
         );
         if (expected.length > 0) {
-            message += String.format(
-                ", expecting '%s'",
-                Arrays.toString(expected)
-            );
+            msg += String.format(", expecting %s", Arrays.toString(expected));
         }
-        return message;
+        return msg;
     }
 }
