@@ -1,7 +1,7 @@
 /*
  * The MIT License
  *
- * Copyright 2012-2015 Zafar Khaja <zafarkhaja@gmail.com>.
+ * Copyright 2012-2024 Zafar Khaja <zafarkhaja@gmail.com>.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -33,7 +33,7 @@ import static com.github.zafarkhaja.semver.VersionParser.CharType.*;
 /**
  * A parser for the SemVer Version.
  *
- * @author Zafar Khaja <zafarkhaja@gmail.com>
+ * @author Zafar Khaja {@literal <zafarkhaja@gmail.com>}
  * @since 0.7.0
  */
 class VersionParser implements Parser<Version> {
@@ -41,7 +41,7 @@ class VersionParser implements Parser<Version> {
     /**
      * Valid character types.
      */
-    static enum CharType implements Stream.ElementType<Character> {
+    enum CharType implements Stream.ElementType<Character> {
 
         DIGIT {
             /**
@@ -145,6 +145,11 @@ class VersionParser implements Parser<Version> {
         }
     }
 
+    /**
+     * Indicates if the parser is in strict mode.
+     */
+    private final boolean isStrictModeOn;
+
     /**
      * The stream of characters.
      */
@@ -158,6 +163,18 @@ class VersionParser implements Parser<Version> {
      * @throws IllegalArgumentException if the input string is {@code NULL} or empty
      */
     VersionParser(String input) {
+        this(input, true);
+    }
+
+    /**
+     * Constructs a {@code VersionParser} instance with an input string to parse.
+     *
+     * @param input an input string to parse
+     * @param strictModeOn a switch to turn the strict parsing mode on and off
+     */
+    VersionParser(String input, boolean strictModeOn) {
+        isStrictModeOn = strictModeOn;
+
         if (input == null || input.isEmpty()) {
             throw new IllegalArgumentException("Input string is NULL or empty");
         }
@@ -165,7 +182,7 @@ class VersionParser implements Parser<Version> {
         for (int i = 0; i < input.length(); i++) {
             elements[i] = input.charAt(i);
         }
-        chars = new Stream<Character>(elements);
+        chars = new Stream<>(elements);
     }
 
     /**
@@ -191,7 +208,21 @@ class VersionParser implements Parser<Version> {
      * @throws UnexpectedCharacterException when encounters an unexpected character type
      */
     static Version parseValidSemVer(String version) {
-        VersionParser parser = new VersionParser(version);
+        return parseValidSemVer(version, true);
+    }
+
+    /**
+     * Parses the whole version including pre-release version and build metadata.
+     *
+     * @param version a version string to parse
+     * @param strictModeOn a switch to turn the strict parsing mode on and off
+     * @return a valid version instance
+     * @throws IllegalArgumentException if the input string is {@code NULL} or empty
+     * @throws ParseException when there is a grammar error
+     * @throws UnexpectedCharacterException when encounters an unexpected character type
+     */
+    static Version parseValidSemVer(String version, boolean strictModeOn) {
+        VersionParser parser = new VersionParser(version, strictModeOn);
         return parser.parseValidSemVer();
     }
 
@@ -199,42 +230,47 @@ class VersionParser implements Parser<Version> {
      * Parses the version core.
      *
      * @param versionCore the version core string to parse
-     * @return a valid normal version object
+     * @return a valid version object
      * @throws IllegalArgumentException if the input string is {@code NULL} or empty
      * @throws ParseException when there is a grammar error
      * @throws UnexpectedCharacterException when encounters an unexpected character type
      */
-    static NormalVersion parseVersionCore(String versionCore) {
+    static Version parseVersionCore(String versionCore) {
         VersionParser parser = new VersionParser(versionCore);
-        return parser.parseVersionCore();
+        long[] versionParts = parser.parseVersionCore();
+        return Version.of(versionParts[0], versionParts[1], versionParts[2]);
     }
 
     /**
      * Parses the pre-release version.
      *
      * @param preRelease the pre-release version string to parse
-     * @return a valid pre-release version object
+     * @return an array of pre-release identifiers
      * @throws IllegalArgumentException if the input string is {@code NULL} or empty
      * @throws ParseException when there is a grammar error
      * @throws UnexpectedCharacterException when encounters an unexpected character type
      */
-    static MetadataVersion parsePreRelease(String preRelease) {
+    static String[] parsePreRelease(String preRelease) {
         VersionParser parser = new VersionParser(preRelease);
-        return parser.parsePreRelease();
+        String[] result = parser.parsePreRelease();
+        parser.ensureValidLookahead(EOI);
+        return result;
     }
 
     /**
      * Parses the build metadata.
      *
      * @param build the build metadata string to parse
-     * @return a valid build metadata object
+     * @return an array of build identifiers
      * @throws IllegalArgumentException if the input string is {@code NULL} or empty
      * @throws ParseException when there is a grammar error
      * @throws UnexpectedCharacterException when encounters an unexpected character type
      */
-    static MetadataVersion parseBuild(String build) {
+    static String[] parseBuild(String build) {
         VersionParser parser = new VersionParser(build);
-        return parser.parseBuild();
+        String[] result = parser.parseBuild();
+        parser.ensureValidLookahead(EOI);
+        return result;
     }
 
     /**
@@ -252,22 +288,20 @@ class VersionParser implements Parser<Version> {
      * @return a valid version object
      */
     private Version parseValidSemVer() {
-        NormalVersion normal = parseVersionCore();
-        MetadataVersion preRelease = MetadataVersion.NULL;
-        MetadataVersion build = MetadataVersion.NULL;
+        long[] versionParts = parseVersionCore();
+        String[] preRelease = new String[0];
+        String[] build = new String[0];
 
         Character next = consumeNextCharacter(HYPHEN, PLUS, EOI);
         if (HYPHEN.isMatchedBy(next)) {
             preRelease = parsePreRelease();
             next = consumeNextCharacter(PLUS, EOI);
-            if (PLUS.isMatchedBy(next)) {
-                build = parseBuild();
-            }
-        } else if (PLUS.isMatchedBy(next)) {
+        }
+        if (PLUS.isMatchedBy(next)) {
             build = parseBuild();
         }
         consumeNextCharacter(EOI);
-        return new Version(normal, preRelease, build);
+        return new Version(versionParts[0], versionParts[1], versionParts[2], preRelease, build);
     }
 
     /**
@@ -279,15 +313,24 @@ class VersionParser implements Parser<Version> {
      * }
      * </pre>
      *
-     * @return a valid normal version object
+     * @return an array of the version core parts
      */
-    private NormalVersion parseVersionCore() {
-        int major = Integer.parseInt(numericIdentifier());
-        consumeNextCharacter(DOT);
-        int minor = Integer.parseInt(numericIdentifier());
-        consumeNextCharacter(DOT);
-        int patch = Integer.parseInt(numericIdentifier());
-        return new NormalVersion(major, minor, patch);
+    private long[] parseVersionCore() {
+        long major = numericIdentifier();
+
+        long minor = 0;
+        if (isStrictModeOn || chars.positiveLookahead(DOT)) {
+            consumeNextCharacter(DOT);
+            minor = numericIdentifier();
+        }
+
+        long patch = 0;
+        if (isStrictModeOn || chars.positiveLookahead(DOT)) {
+            consumeNextCharacter(DOT);
+            patch = numericIdentifier();
+        }
+
+        return new long[] {major, minor, patch};
     }
 
     /**
@@ -302,11 +345,11 @@ class VersionParser implements Parser<Version> {
      * }
      * </pre>
      *
-     * @return a valid pre-release version object
+     * @return an array of pre-release identifiers
      */
-    private MetadataVersion parsePreRelease() {
+    private String[] parsePreRelease() {
         ensureValidLookahead(DIGIT, LETTER, HYPHEN);
-        List<String> idents = new ArrayList<String>();
+        List<String> idents = new ArrayList<>();
         do {
             idents.add(preReleaseIdentifier());
             if (chars.positiveLookahead(DOT)) {
@@ -315,7 +358,7 @@ class VersionParser implements Parser<Version> {
             }
             break;
         } while (true);
-        return new MetadataVersion(idents.toArray(new String[idents.size()]));
+        return idents.toArray(new String[0]);
     }
 
     /**
@@ -336,7 +379,7 @@ class VersionParser implements Parser<Version> {
         if (chars.positiveLookaheadBefore(boundary, LETTER, HYPHEN)) {
             return alphanumericIdentifier();
         } else {
-            return numericIdentifier();
+            return String.valueOf(numericIdentifier());
         }
     }
 
@@ -352,11 +395,11 @@ class VersionParser implements Parser<Version> {
      * }
      * </pre>
      *
-     * @return a valid build metadata object
+     * @return an array of build identifiers
      */
-    private MetadataVersion parseBuild() {
+    private String[] parseBuild() {
         ensureValidLookahead(DIGIT, LETTER, HYPHEN);
-        List<String> idents = new ArrayList<String>();
+        List<String> idents = new ArrayList<>();
         do {
             idents.add(buildIdentifier());
             if (chars.positiveLookahead(DOT)) {
@@ -365,7 +408,7 @@ class VersionParser implements Parser<Version> {
             }
             break;
         } while (true);
-        return new MetadataVersion(idents.toArray(new String[idents.size()]));
+        return idents.toArray(new String[0]);
     }
 
     /**
@@ -403,9 +446,13 @@ class VersionParser implements Parser<Version> {
      *
      * @return a string representing the numeric identifier
      */
-    private String numericIdentifier() {
+    private long numericIdentifier() {
         checkForLeadingZeroes();
-        return digits();
+        try {
+            return Long.parseLong(digits());
+        } catch (NumberFormatException e) {
+            throw new ParseException("Numeric identifier overflow");
+        }
     }
 
     /**
