@@ -1,7 +1,7 @@
 /*
  * The MIT License
  *
- * Copyright 2012-2015 Zafar Khaja <zafarkhaja@gmail.com>.
+ * Copyright 2012-2024 Zafar Khaja <zafarkhaja@gmail.com>.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -24,16 +24,17 @@
 package com.github.zafarkhaja.semver.expr;
 
 import com.github.zafarkhaja.semver.Version;
+import java.util.function.Predicate;
 
 /**
  * The {@code Expression} interface is to be implemented
  * by the nodes of the Abstract Syntax Tree produced by
  * the {@code ExpressionParser} class.
  *
- * @author Zafar Khaja <zafarkhaja@gmail.com>
+ * @author Zafar Khaja {@literal <zafarkhaja@gmail.com>}
  * @since 0.7.0
  */
-public interface Expression {
+public interface Expression extends Predicate<Version> {
 
     /**
      * Interprets the expression.
@@ -42,4 +43,8 @@ public interface Expression {
      * @return the result of the expression interpretation
      */
     boolean interpret(Version version);
+
+    default boolean test(Version version) {
+        return interpret(version);
+    }
 }
