@@ -1,7 +1,7 @@
 /*
  * The MIT License
  *
- * Copyright 2012-2015 Zafar Khaja <zafarkhaja@gmail.com>.
+ * Copyright 2012-2024 Zafar Khaja <zafarkhaja@gmail.com>.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -29,11 +29,13 @@ import com.github.zafarkhaja.semver.ParseException;
  * Thrown during the lexical analysis when
  * an illegal character is encountered.
  *
- * @author Zafar Khaja <zafarkhaja@gmail.com>
+ * @author Zafar Khaja {@literal <zafarkhaja@gmail.com>}
  * @since 0.7.0
  */
 public class LexerException extends ParseException {
 
+    private static final long serialVersionUID = 0L;
+
     /**
      * The string being analyzed starting from an illegal character.
      */
@@ -46,6 +48,8 @@ public class LexerException extends ParseException {
      * @param expr the string starting from an illegal character
      */
     LexerException(String expr) {
+        super("Illegal character near '" + expr + "'");
+
         this.expr = expr;
     }
 
@@ -56,6 +60,6 @@ public class LexerException extends ParseException {
      */
     @Override
     public String toString() {
-        return "Illegal character near '" + expr + "'";
+        return getMessage();
     }
 }
