@@ -1,7 +1,7 @@
 /*
  * The MIT License
  *
- * Copyright 2012-2015 Zafar Khaja <zafarkhaja@gmail.com>.
+ * Copyright 2012-2024 Zafar Khaja <zafarkhaja@gmail.com>.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -31,11 +31,13 @@ import java.util.Arrays;
 /**
  * Thrown when a token of unexpected types is encountered during the parsing.
  *
- * @author Zafar Khaja <zafarkhaja@gmail.com>
+ * @author Zafar Khaja {@literal <zafarkhaja@gmail.com>}
  * @since 0.7.0
  */
 public class UnexpectedTokenException extends ParseException {
 
+    private static final long serialVersionUID = 0L;
+
     /**
      * The unexpected token.
      */
@@ -53,19 +55,23 @@ public class UnexpectedTokenException extends ParseException {
      * @param cause the wrapped exception
      */
     UnexpectedTokenException(UnexpectedElementException cause) {
-        unexpected = (Token) cause.getUnexpectedElement();
-        expected   = (Token.Type[]) cause.getExpectedElementTypes();
+        this(
+            (Token) cause.getUnexpectedElement(),
+            (Token.Type[]) cause.getExpectedElementTypes()
+        );
     }
 
     /**
      * Constructs a {@code UnexpectedTokenException} instance
      * with the unexpected token and the expected types.
      *
-     * @param token the unexpected token
+     * @param unexpected the unexpected token
      * @param expected an array of the expected token types
      */
-    UnexpectedTokenException(Token token, Token.Type... expected) {
-        unexpected = token;
+    UnexpectedTokenException(Token unexpected, Token.Type... expected) {
+        super(createMessage(unexpected, expected));
+
+        this.unexpected = unexpected;
         this.expected = expected;
     }
 
@@ -96,16 +102,14 @@ public class UnexpectedTokenException extends ParseException {
      */
     @Override
     public String toString() {
-        String message = String.format(
-            "Unexpected token '%s'",
-            unexpected
-        );
+        return getMessage();
+    }
+
+    private static String createMessage(Token unexpected, Token.Type... expected) {
+        String msg = String.format("Unexpected token %s", unexpected);
         if (expected.length > 0) {
-            message += String.format(
-                ", expecting '%s'",
-                Arrays.toString(expected)
-            );
+            msg += String.format(", expecting %s", Arrays.toString(expected));
         }
-        return message;
+        return msg;
     }
 }
